/**
* Title: 		 MyTransformer
* Description:	 Simple dummy transformer used to modify the flow's payload 
* Copyright:     Copyright (c) 2015
* Company:       Morpheus Quality Technologies
* Creation date: 11-03-2015
* Last modified: 28-08-2015
* @author 		 Stefano Adriani
* @version 		 1.0
*/

package transformers;

import org.mule.api.transformer.TransformerException;
import org.mule.transformer.AbstractTransformer;

/**
* Usage of this class is OPTIONAL in the context of this example:
* it's possible to comment/uncomment the reference to the component implemented by this class
* (in the "hello_world.xml" file) without affecting the main functionality.<br/><br/>
* 
* The XML element using this class can be found in the "src/main/app/hello_world.xml" file as
* a "custom-transformer" Mule's component.<br/><br/> 
* 
* When enabled (i.e. not commented) this component just logs some information on STDOUT and add
* the "PAYLOAD" prefix to the payload, that will be returned as text/plain HTTP GET response.
*/
public class MyTransformer extends AbstractTransformer {
	
  	/** If <code>true</code> some info messages are printed on STDOUT.										*/
	protected static 		boolean			verbose		 		= true;
	
  	/** Beginning of each logging message produced by this class.											*/
	protected static 		String			leadingName 		= "MyTransformer - ";

	/**
	* Core method, invoked when the flow reaches the component bound to this class.
	* MUST BE implemented since we are extending the <code>AbstractTransformer</code> class,
	* where this method is defined as <em>abstract</em>.
	* 
	* @param the input payload, as received from previous flow's component
	* @param the encoding (if any) associated to the input payload
	* @return the output payload, to be passed to next flow's component
	*/
	@Override
	protected Object doTransform(Object src, String enc) throws TransformerException {
		
		if (verbose) {
			System.out.println(leadingName + "Input object   : " + src);
			System.out.println(leadingName + "Input encoding : " + enc);
			System.out.println(leadingName + "Java version   : " + System.getProperty("java.version"));
		}
		// Adding a prefix to current payload (and removing the first blank char contained in the input payload)
		return "PAYLOAD: " + src.toString().substring(1);
	}
	
} // End of class